Installation
============
If you are using pip, you can simply run ::

  pip install symfit

from your terminal. If you are using linux and do not use pip, you can download
the source from https://github.com/tBuLi/symfit and install manually.

Are you not on linux and you do not use pip? That's your own mess.

Contrib module
--------------
To also install the dependencies of 3rd party contrib modules such as
interactive guesses, install `symfit` using::

  pip install symfit[contrib]

Dependencies
------------
::

  pip install sympy
  pip install numpy
  pip install scipy
